Module protobuf

Module protobuf 

Modules

__buffa
field
value

Structs

Any
Any contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message.
AnyOwnedView
Self-contained, 'static owned view of a Any message.
AnyView
Any contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message.
Api
Api is a light-weight descriptor for an API Interface.
ApiOwnedView
Self-contained, 'static owned view of a Api message.
ApiView
Api is a light-weight descriptor for an API Interface.
BoolValue
Wrapper message for bool.
BoolValueOwnedView
Self-contained, 'static owned view of a BoolValue message.
BoolValueView
Wrapper message for bool.
BytesValue
Wrapper message for bytes.
BytesValueOwnedView
Self-contained, 'static owned view of a BytesValue message.
BytesValueView
Wrapper message for bytes.
DoubleValue
Wrapper message for double.
DoubleValueOwnedView
Self-contained, 'static owned view of a DoubleValue message.
DoubleValueView
Wrapper message for double.
Duration
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like “day” or “month”. It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years.
DurationOwnedView
Self-contained, 'static owned view of a Duration message.
DurationView
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like “day” or “month”. It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years.
Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
EmptyOwnedView
Self-contained, 'static owned view of a Empty message.
EmptyView
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Enum
Enum type definition.
EnumOwnedView
Self-contained, 'static owned view of a Enum message.
EnumValue
Enum value definition.
EnumValueOwnedView
Self-contained, 'static owned view of a EnumValue message.
EnumValueView
Enum value definition.
EnumView
Enum type definition.
Field
A single field of a message type.
FieldMask
FieldMask represents a set of symbolic field paths, for example:
FieldMaskOwnedView
Self-contained, 'static owned view of a FieldMask message.
FieldMaskView
FieldMask represents a set of symbolic field paths, for example:
FieldOwnedView
Self-contained, 'static owned view of a Field message.
FieldView
A single field of a message type.
FloatValue
Wrapper message for float.
FloatValueOwnedView
Self-contained, 'static owned view of a FloatValue message.
FloatValueView
Wrapper message for float.
Int32Value
Wrapper message for int32.
Int32ValueOwnedView
Self-contained, 'static owned view of a Int32Value message.
Int32ValueView
Wrapper message for int32.
Int64Value
Wrapper message for int64.
Int64ValueOwnedView
Self-contained, 'static owned view of a Int64Value message.
Int64ValueView
Wrapper message for int64.
ListValue
ListValue is a wrapper around a repeated field of values.
ListValueOwnedView
Self-contained, 'static owned view of a ListValue message.
ListValueView
ListValue is a wrapper around a repeated field of values.
Method
Method represents a method of an API interface.
MethodOwnedView
Self-contained, 'static owned view of a Method message.
MethodView
Method represents a method of an API interface.
Mixin
Declares an API Interface to be included in this interface. The including interface must redeclare all the methods from the included interface, but documentation and options are inherited as follows:
MixinOwnedView
Self-contained, 'static owned view of a Mixin message.
MixinView
Declares an API Interface to be included in this interface. The including interface must redeclare all the methods from the included interface, but documentation and options are inherited as follows:
Option
A protocol buffer option, which can be attached to a message, field, enumeration, etc.
OptionOwnedView
Self-contained, 'static owned view of a Option message.
OptionView
A protocol buffer option, which can be attached to a message, field, enumeration, etc.
SourceContext
SourceContext represents information about the source of a protobuf element, like the file in which it is defined.
SourceContextOwnedView
Self-contained, 'static owned view of a SourceContext message.
SourceContextView
SourceContext represents information about the source of a protobuf element, like the file in which it is defined.
StringValue
Wrapper message for string.
StringValueOwnedView
Self-contained, 'static owned view of a StringValue message.
StringValueView
Wrapper message for string.
Struct
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.
StructOwnedView
Self-contained, 'static owned view of a Struct message.
StructView
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.
Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one.
TimestampOwnedView
Self-contained, 'static owned view of a Timestamp message.
TimestampView
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one.
Type
A protocol buffer message type.
TypeOwnedView
Self-contained, 'static owned view of a Type message.
TypeView
A protocol buffer message type.
UInt32Value
Wrapper message for uint32.
UInt32ValueOwnedView
Self-contained, 'static owned view of a UInt32Value message.
UInt32ValueView
Wrapper message for uint32.
UInt64Value
Wrapper message for uint64.
UInt64ValueOwnedView
Self-contained, 'static owned view of a UInt64Value message.
UInt64ValueView
Wrapper message for uint64.
Value
Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.
ValueOwnedView
Self-contained, 'static owned view of a Value message.
ValueView
Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

Enums

NullValue
NullValue is a singleton enumeration to represent the null value for the Value type union.
Syntax
The syntax in which a protocol buffer element is defined.

Constants

FILE_DESCRIPTOR_SET_BYTESreflect
The serialized FileDescriptorSet this package’s descriptor pool is built from (source_code_info stripped). Re-exported from __buffa::reflect. The serialized FileDescriptorSet for this codegen run, including transitive dependencies, with source_code_info stripped. Used to build the runtime DescriptorPool; also suitable for shipping the schema over the wire. Re-exported at the package root — prefer that path over going through __buffa.

Functions

descriptor_poolreflect
The lazily-built descriptor pool for this package’s Reflectable impls. Re-exported from __buffa::reflect. The lazily-built descriptor pool for this package’s Reflectable impls. Built from FILE_DESCRIPTOR_SET_BYTES on first access.