ApiView

Struct ApiView 

pub struct ApiView<'a> {
    pub name: &'a str,
    pub methods: RepeatedView<'a, MethodView<'a>>,
    pub options: RepeatedView<'a, OptionView<'a>>,
    pub version: &'a str,
    pub source_context: MessageFieldView<SourceContextView<'a>>,
    pub mixins: RepeatedView<'a, MixinView<'a>>,
    pub syntax: EnumValue<Syntax>,
    pub edition: &'a str,
    pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}
Api is a light-weight descriptor for an API Interface.

Interfaces are also described as “protocol buffer services” in some contexts, such as by the “service” keyword in a .proto file, but they are different from API Services, which represent a concrete implementation of an interface as opposed to simply a description of methods and bindings. They are also sometimes simply referred to as “APIs” in other contexts, such as the name of this message itself. See https://cloud.google.com/apis/design/glossary for detailed terminology.

New usages of this message as an alternative to ServiceDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Fields

name: &'a str

The fully qualified name of this interface, including package name followed by the interface’s simple name.

Field 1: name

methods: RepeatedView<'a, MethodView<'a>>

The methods of this interface, in unspecified order.

Field 2: methods

options: RepeatedView<'a, OptionView<'a>>

Any metadata attached to the interface.

Field 3: options

version: &'a str

A version string for this interface. If specified, must have the form major-version.minor-version, as in 1.10. If the minor version is omitted, it defaults to zero. If the entire version field is empty, the major version is derived from the package name, as outlined below. If the field is not empty, the version in the package name will be verified to be consistent with what is provided here.

The versioning schema uses [semantic versioning](http://semver.org) where the major version number indicates a breaking change and the minor version an additive, non-breaking change. Both version numbers are signals to users what to expect from different versions, and should be carefully chosen based on the product plan.

The major version is also reflected in the package name of the interface, which must end in v<major-version>, as in google.feature.v1. For major versions 0 and 1, the suffix can be omitted. Zero major versions must only be used for experimental, non-GA interfaces.

Field 4: version

source_context: MessageFieldView<SourceContextView<'a>>

Source context for the protocol buffer service represented by this message.

Field 5: source_context

mixins: RepeatedView<'a, MixinView<'a>>

Included interfaces. See Mixin.

Field 6: mixins

syntax: EnumValue<Syntax>

The source syntax of the service.

Field 7: syntax

edition: &'a str

The source edition string, only valid when syntax is SYNTAX_EDITIONS.

Field 8: edition

__buffa_unknown_fields: UnknownFieldsView<'a>