pub struct DoubleValueView<'a> {
pub value: f64,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Expand description
Wrapper message for double.
The JSON representation for DoubleValue is JSON number.
Fields
value: f64The double value.
Field 1: value
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for DoubleValueView<'a>
impl<'a> Clone for DoubleValueView<'a>
Sourcefn clone(&self) -> DoubleValueView<'a>
fn clone(&self) -> DoubleValueView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for DoubleValueView<'a>
impl<'a> Debug for DoubleValueView<'a>
Sourceimpl<'a> Default for DoubleValueView<'a>
impl<'a> Default for DoubleValueView<'a>
Sourcefn default() -> DoubleValueView<'a>
fn default() -> DoubleValueView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for DoubleValueView<'static>
impl DefaultViewInstance for DoubleValueView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for DoubleValueView<'a>
impl<'a> HasDefaultViewInstance for DoubleValueView<'a>
Sourcetype Static = DoubleValueView<'static>
type Static = DoubleValueView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for DoubleValueView<'a>
impl<'a> MessageView<'a> for DoubleValueView<'a>
Sourcefn to_owned_message(&self) -> DoubleValue
fn to_owned_message(&self) -> DoubleValue
Convert this view to the owned message type.
Sourcetype Owned = DoubleValue
type Owned = DoubleValue
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more