pub struct Empty { /* private fields */ }Expand description
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Example usage: gRPC uses google.protobuf.Empty as the input and output type for RPCs defined as returning or accepting “nothing”:
rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);Implementations