pub struct EmptyView<'a> {
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Expand description
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Example usage: gRPC uses google.protobuf.Empty as the input and output type for RPCs defined as returning or accepting “nothing”:
rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);Fields
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl DefaultViewInstance for EmptyView<'static>
impl DefaultViewInstance for EmptyView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for EmptyView<'a>
impl<'a> HasDefaultViewInstance for EmptyView<'a>
Sourceimpl<'a> MessageView<'a> for EmptyView<'a>
impl<'a> MessageView<'a> for EmptyView<'a>
Sourcefn to_owned_message(&self) -> Empty
fn to_owned_message(&self) -> Empty
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more