pub struct Enum {
pub name: String,
pub enumvalue: Vec<EnumValue>,
pub options: Vec<Option>,
pub source_context: MessageField<SourceContext, Inline<SourceContext>>,
pub syntax: EnumValue<Syntax>,
pub edition: String,
/* private fields */
}Expand description
Enum type definition.
New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Fields
name: StringEnum type name.
Field 1: name
enumvalue: Vec<EnumValue>Enum value definitions.
Field 2: enumvalue
options: Vec<Option>Protocol buffer options.
Field 3: options
source_context: MessageField<SourceContext, Inline<SourceContext>>The source context.
Field 4: source_context
syntax: EnumValue<Syntax>The source syntax.
Field 5: syntax
edition: StringThe source edition string, only valid when syntax is SYNTAX_EDITIONS.
Field 6: edition
Implementations