pub struct EnumValue {
pub name: String,
pub number: i32,
pub options: Vec<Option>,
/* private fields */
}Expand description
Enum value definition.
New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Fields
name: StringEnum value name.
Field 1: name
number: i32Enum value number.
Field 2: number
options: Vec<Option>Protocol buffer options.
Field 3: options
Implementations