pub struct Field {
pub kind: EnumValue<Kind>,
pub cardinality: EnumValue<Cardinality>,
pub number: i32,
pub name: String,
pub type_url: String,
pub oneof_index: i32,
pub packed: bool,
pub options: Vec<Option>,
pub json_name: String,
pub default_value: String,
/* private fields */
}Expand description
A single field of a message type.
New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Fields
kind: EnumValue<Kind>The field type.
Field 1: kind
cardinality: EnumValue<Cardinality>The field cardinality.
Field 2: cardinality
number: i32The field number.
Field 3: number
name: StringThe field name.
Field 4: name
type_url: StringThe field type URL, without the scheme, for message or enumeration
types. Example: "type.googleapis.com/google.protobuf.Timestamp".
Field 6: type_url
oneof_index: i32The index of the field type in Type.oneofs, for message or enumeration
types. The first type has index 1; zero means the type is not in the list.
Field 7: oneof_index
packed: boolWhether to use alternative packed wire representation.
Field 8: packed
options: Vec<Option>The protocol buffer options.
Field 9: options
json_name: StringThe field JSON name.
Field 10: json_name
default_value: StringThe string value of the default value of this field. Proto2 syntax only.
Field 11: default_value
Implementations