FieldView

Struct FieldView 

pub struct FieldView<'a> {
    pub kind: EnumValue<Kind>,
    pub cardinality: EnumValue<Cardinality>,
    pub number: i32,
    pub name: &'a str,
    pub type_url: &'a str,
    pub oneof_index: i32,
    pub packed: bool,
    pub options: RepeatedView<'a, OptionView<'a>>,
    pub json_name: &'a str,
    pub default_value: &'a str,
    pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}
A single field of a message type.

New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Fields

kind: EnumValue<Kind>

The field type.

Field 1: kind

cardinality: EnumValue<Cardinality>

The field cardinality.

Field 2: cardinality

number: i32

The field number.

Field 3: number

name: &'a str

The field name.

Field 4: name

type_url: &'a str

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp".

Field 6: type_url

oneof_index: i32

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list.

Field 7: oneof_index

packed: bool

Whether to use alternative packed wire representation.

Field 8: packed

options: RepeatedView<'a, OptionView<'a>>

The protocol buffer options.

Field 9: options

json_name: &'a str

The field JSON name.

Field 10: json_name

default_value: &'a str

The string value of the default value of this field. Proto2 syntax only.

Field 11: default_value

__buffa_unknown_fields: UnknownFieldsView<'a>