pub struct Int32ValueView<'a> {
pub value: i32,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Expand description
Wrapper message for int32.
The JSON representation for Int32Value is JSON number.
Fields
value: i32The int32 value.
Field 1: value
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for Int32ValueView<'a>
impl<'a> Clone for Int32ValueView<'a>
Sourcefn clone(&self) -> Int32ValueView<'a>
fn clone(&self) -> Int32ValueView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for Int32ValueView<'a>
impl<'a> Debug for Int32ValueView<'a>
Sourceimpl<'a> Default for Int32ValueView<'a>
impl<'a> Default for Int32ValueView<'a>
Sourcefn default() -> Int32ValueView<'a>
fn default() -> Int32ValueView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for Int32ValueView<'static>
impl DefaultViewInstance for Int32ValueView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for Int32ValueView<'a>
impl<'a> HasDefaultViewInstance for Int32ValueView<'a>
Sourcetype Static = Int32ValueView<'static>
type Static = Int32ValueView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for Int32ValueView<'a>
impl<'a> MessageView<'a> for Int32ValueView<'a>
Sourcefn to_owned_message(&self) -> Int32Value
fn to_owned_message(&self) -> Int32Value
Convert this view to the owned message type.
Sourcetype Owned = Int32Value
type Owned = Int32Value
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more