pub struct Method {
pub name: String,
pub request_type_url: String,
pub request_streaming: bool,
pub response_type_url: String,
pub response_streaming: bool,
pub options: Vec<Option>,
pub syntax: EnumValue<Syntax>,
pub edition: String,
/* private fields */
}Expand description
Method represents a method of an API interface.
New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Fields
name: StringThe simple name of this method.
Field 1: name
request_type_url: StringA URL of the input message type.
Field 2: request_type_url
request_streaming: boolIf true, the request is streamed.
Field 3: request_streaming
response_type_url: StringThe URL of the output message type.
Field 4: response_type_url
response_streaming: boolIf true, the response is streamed.
Field 5: response_streaming
options: Vec<Option>Any metadata attached to the method.
Field 6: options
syntax: EnumValue<Syntax>The source syntax of this method.
This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue.
Field 7: syntax
edition: StringThe source edition string, only valid when syntax is SYNTAX_EDITIONS.
This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue.
Field 8: edition
Implementations