pub struct StringValueView<'a> {
pub value: &'a str,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
value: &'a strField 1: value
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for StringValueView<'a>
impl<'a> Clone for StringValueView<'a>
Sourcefn clone(&self) -> StringValueView<'a>
fn clone(&self) -> StringValueView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for StringValueView<'a>
impl<'a> Debug for StringValueView<'a>
Sourceimpl<'a> Default for StringValueView<'a>
impl<'a> Default for StringValueView<'a>
Sourcefn default() -> StringValueView<'a>
fn default() -> StringValueView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for StringValueView<'static>
impl DefaultViewInstance for StringValueView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for StringValueView<'a>
impl<'a> HasDefaultViewInstance for StringValueView<'a>
Sourcetype Static = StringValueView<'static>
type Static = StringValueView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for StringValueView<'a>
impl<'a> MessageView<'a> for StringValueView<'a>
Sourcefn to_owned_message(&self) -> StringValue
fn to_owned_message(&self) -> StringValue
Convert this view to the owned message type.
Sourcetype Owned = StringValue
type Owned = StringValue
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more