Struct

Struct Struct 

pub struct Struct {
    pub fields: HashMap<String, Value>,
    /* private fields */
}
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.

The JSON representation for Struct is JSON object.

Fields

fields: HashMap<String, Value>

Unordered map of dynamically typed values.

Field 1: fields

Implementations

Source

impl Struct

pub fn new() -> Self

Construct a new empty Struct.

pub fn from_fields( fields: impl IntoIterator<Item = (impl Into<String>, impl Into<Value>)>, ) -> Self

Construct a Struct from an iterator of key-value pairs.

Example
use buffa_types::google::protobuf::{Struct, Value};

let s = Struct::from_fields([("x", Value::from(1.0_f64)), ("y", Value::from(2.0_f64))]);
assert!(s.get("x").is_some());
pub fn insert(&mut self, key: impl Into<String>, value: impl Into<Value>)

Insert a key-value pair into the struct.

pub fn get(&self, key: &str) -> Option<&Value>

Returns the value for key if present.

Source

impl Struct

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.Struct"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>