pub struct Type {
pub name: String,
pub fields: Vec<Field>,
pub oneofs: Vec<String>,
pub options: Vec<Option>,
pub source_context: MessageField<SourceContext, Inline<SourceContext>>,
pub syntax: EnumValue<Syntax>,
pub edition: String,
/* private fields */
}Expand description
A protocol buffer message type.
New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Fields
name: StringThe fully qualified message name.
Field 1: name
fields: Vec<Field>The list of fields.
Field 2: fields
oneofs: Vec<String>The list of types appearing in oneof definitions in this type.
Field 3: oneofs
options: Vec<Option>The protocol buffer options.
Field 4: options
source_context: MessageField<SourceContext, Inline<SourceContext>>The source context.
Field 5: source_context
syntax: EnumValue<Syntax>The source syntax.
Field 6: syntax
edition: StringThe source edition string, only valid when syntax is SYNTAX_EDITIONS.
Field 7: edition
Implementations