pub struct UInt64ValueView<'a> {
pub value: u64,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Expand description
Wrapper message for uint64.
The JSON representation for UInt64Value is JSON string.
Fields
value: u64The uint64 value.
Field 1: value
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for UInt64ValueView<'a>
impl<'a> Clone for UInt64ValueView<'a>
Sourcefn clone(&self) -> UInt64ValueView<'a>
fn clone(&self) -> UInt64ValueView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for UInt64ValueView<'a>
impl<'a> Debug for UInt64ValueView<'a>
Sourceimpl<'a> Default for UInt64ValueView<'a>
impl<'a> Default for UInt64ValueView<'a>
Sourcefn default() -> UInt64ValueView<'a>
fn default() -> UInt64ValueView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for UInt64ValueView<'static>
impl DefaultViewInstance for UInt64ValueView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for UInt64ValueView<'a>
impl<'a> HasDefaultViewInstance for UInt64ValueView<'a>
Sourcetype Static = UInt64ValueView<'static>
type Static = UInt64ValueView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for UInt64ValueView<'a>
impl<'a> MessageView<'a> for UInt64ValueView<'a>
Sourcefn to_owned_message(&self) -> UInt64Value
fn to_owned_message(&self) -> UInt64Value
Convert this view to the owned message type.
Sourcetype Owned = UInt64Value
type Owned = UInt64Value
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more