pub struct Value {
pub kind: Option<Kind>,
/* private fields */
}Expand description
Value represents a dynamically typed value which can be either
null, a number, a string, a boolean, a recursive struct value, or a
list of values. A producer of value is expected to set one of these
variants. Absence of any variant indicates an error.
The JSON representation for Value is JSON value.
Fields
kind: Option<Kind>Implementations
Sourceimpl Value
impl Value
Sourcepub fn as_number(&self) -> Option<f64>
pub fn as_number(&self) -> Option<f64>
Returns the f64 value if this is a number, otherwise None.
Sourcepub fn as_str(&self) -> Option<&str>
pub fn as_str(&self) -> Option<&str>
Returns the string value if this is a string, otherwise None.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value if this is a bool, otherwise None.
Sourcepub fn as_struct(&self) -> Option<&Struct>
pub fn as_struct(&self) -> Option<&Struct>
Returns a reference to the Struct if this is a struct value.
Sourcepub fn as_list(&self) -> Option<&ListValue>
pub fn as_list(&self) -> Option<&ListValue>
Returns a reference to the ListValue if this is a list value.
Sourcepub fn as_struct_mut(&mut self) -> Option<&mut Struct>
pub fn as_struct_mut(&mut self) -> Option<&mut Struct>
Returns a mutable reference to the Struct if this is a struct value.
Sourcepub fn as_list_mut(&mut self) -> Option<&mut ListValue>
pub fn as_list_mut(&mut self) -> Option<&mut ListValue>
Returns a mutable reference to the ListValue if this is a list value.