Module protobuf

Module protobuf 

Modules

__buffa

Structs

Any
Any contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message.
BoolValue
Wrapper message for bool.
BytesValue
Wrapper message for bytes.
DoubleValue
Wrapper message for double.
Duration
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like “day” or “month”. It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +-10,000 years.
Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
FieldMask
FieldMask represents a set of symbolic field paths, for example:
FloatValue
Wrapper message for float.
Int32Value
Wrapper message for int32.
Int64Value
Wrapper message for int64.
ListValue
ListValue is a wrapper around a repeated field of values.
StringValue
Wrapper message for string.
Struct
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.
Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one.
UInt32Value
Wrapper message for uint32.
UInt64Value
Wrapper message for uint64.
Value
Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants. Absence of any variant indicates an error.

Enums

NullValue
NullValue is a singleton enumeration to represent the null value for the Value type union.