pub struct AnyView<'a> {
pub type_url: &'a str,
pub value: &'a [u8],
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
type_url: &'a strField 1: type_url
value: &'a [u8]Field 2: value
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl DefaultViewInstance for AnyView<'static>
impl DefaultViewInstance for AnyView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for AnyView<'a>
impl<'a> HasDefaultViewInstance for AnyView<'a>
Sourceimpl<'a> MessageView<'a> for AnyView<'a>
impl<'a> MessageView<'a> for AnyView<'a>
Sourcefn to_owned_message(&self) -> Any
fn to_owned_message(&self) -> Any
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more