pub struct FloatValueView<'a> {
pub value: f32,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Expand description
Wrapper message for float.
The JSON representation for FloatValue is JSON number.
Fields
value: f32The float value.
Field 1: value
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for FloatValueView<'a>
impl<'a> Clone for FloatValueView<'a>
Sourcefn clone(&self) -> FloatValueView<'a>
fn clone(&self) -> FloatValueView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for FloatValueView<'a>
impl<'a> Debug for FloatValueView<'a>
Sourceimpl<'a> Default for FloatValueView<'a>
impl<'a> Default for FloatValueView<'a>
Sourcefn default() -> FloatValueView<'a>
fn default() -> FloatValueView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for FloatValueView<'static>
impl DefaultViewInstance for FloatValueView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for FloatValueView<'a>
impl<'a> HasDefaultViewInstance for FloatValueView<'a>
Sourcetype Static = FloatValueView<'static>
type Static = FloatValueView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for FloatValueView<'a>
impl<'a> MessageView<'a> for FloatValueView<'a>
Sourcefn to_owned_message(&self) -> FloatValue
fn to_owned_message(&self) -> FloatValue
Convert this view to the owned message type.
Sourcetype Owned = FloatValue
type Owned = FloatValue
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more