StructView

Struct StructView 

pub struct StructView<'a> {
    pub fields: MapView<'a, &'a str, ValueView<'a>>,
    pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.

The JSON representation for Struct is JSON object.

Fields

fields: MapView<'a, &'a str, ValueView<'a>>

Unordered map of dynamically typed values.

Field 1: fields (map)

__buffa_unknown_fields: UnknownFieldsView<'a>