pub struct TimestampView<'a> {
pub seconds: i64,
pub nanos: i32,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
seconds: i64Field 1: seconds
nanos: i32Field 2: nanos
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for TimestampView<'a>
impl<'a> Clone for TimestampView<'a>
Sourcefn clone(&self) -> TimestampView<'a>
fn clone(&self) -> TimestampView<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for TimestampView<'a>
impl<'a> Debug for TimestampView<'a>
Sourceimpl<'a> Default for TimestampView<'a>
impl<'a> Default for TimestampView<'a>
Sourcefn default() -> TimestampView<'a>
fn default() -> TimestampView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for TimestampView<'static>
impl DefaultViewInstance for TimestampView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for TimestampView<'a>
impl<'a> HasDefaultViewInstance for TimestampView<'a>
Sourcetype Static = TimestampView<'static>
type Static = TimestampView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for TimestampView<'a>
impl<'a> MessageView<'a> for TimestampView<'a>
Sourcefn to_owned_message(&self) -> Timestamp
fn to_owned_message(&self) -> Timestamp
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more