Value

Struct Value 

pub struct Value {
    pub kind: Option<Kind>,
    /* private fields */
}

Fields

kind: Option<Kind>

Implementations

Source

impl Value

pub fn null() -> Self

Construct a Value that represents a protobuf null.

pub fn is_null(&self) -> bool

Returns true if this value is the null variant.

pub fn as_number(&self) -> Option<f64>

Returns the f64 value if this is a number, otherwise None.

pub fn as_str(&self) -> Option<&str>

Returns the string value if this is a string, otherwise None.

pub fn as_bool(&self) -> Option<bool>

Returns the bool value if this is a bool, otherwise None.

pub fn as_struct(&self) -> Option<&Struct>

Returns a reference to the Struct if this is a struct value.

pub fn as_list(&self) -> Option<&ListValue>

Returns a reference to the ListValue if this is a list value.

pub fn as_struct_mut(&mut self) -> Option<&mut Struct>

Returns a mutable reference to the Struct if this is a struct value.

pub fn as_list_mut(&mut self) -> Option<&mut ListValue>

Returns a mutable reference to the ListValue if this is a list value.

Source

impl Value

pub const TYPE_URL: &'static str = "type.googleapis.com/google.protobuf.Value"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>